# Iconoclast

[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/iconoclast?logo=python&logoColor=white&style=for-the-badge)](https://pypi.org/project/iconoclast)
[![PyPI](https://img.shields.io/pypi/v/iconoclast?logo=pypi&color=green&logoColor=white&style=for-the-badge)](https://pypi.org/project/iconoclast)
[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/celsiusnarhwal/iconoclast?logo=github&color=orange&logoColor=white&style=for-the-badge)](https://github.com/celsiusnarhwal/iconoclast/releases)
[![PyPI - License](https://img.shields.io/pypi/l/iconoclast?color=03cb98&style=for-the-badge)](https://github.com/celsiusnarhwal/iconoclast/blob/main/LICENSE.md)
[![Code style: Black](https://aegis.celsiusnarhwal.dev/badge/black?style=for-the-badge)](https://github.com/psf/black)

Iconoclast is the easiest way to use [Font Awesome](https://fontawesome.com/) [Pro](https://fontawesome.com/plans)
icons in your [Material for MkDocs](https://squidfunk.github.io/mkdocs-material/) project.

Check out the docs at [iconoclast.celsiusnarhwal.dev](https://iconoclast.celsiusnarhwal.dev).

## License

Iconoclast is licensed under the [MIT LIcense](https://github.com/celsiusnarhwal/iconoclast/blob/main/LICENSE.md).
